@@ -4,8 +4,5 @@ from prettyqt import charts
 from prettyqt.qt import QtCharts
 
 
-QtCharts.QBarSeries.__bases__ = (charts.AbstractBarSeries,)
-
-
-class BarSeries(QtCharts.QBarSeries):
+class BarSeries(charts.AbstractBarSeriesMixin, QtCharts.QBarSeries):
     pass
