@@ -14,10 +14,8 @@ POLAR_ORIENTATIONS = bidict(
 
 PolarOrientationStr = Literal["radial", "angular"]
 
-QtCharts.QPolarChart.__bases__ = (charts.Chart,)
 
-
-class PolarChart(QtCharts.QPolarChart):
+class PolarChart(charts.ChartMixin, QtCharts.QPolarChart):
     def add_axis(self, axis: QtCharts.QAbstractAxis, orientation: PolarOrientationStr):
         if orientation not in POLAR_ORIENTATIONS:
             raise InvalidParamError(orientation, POLAR_ORIENTATIONS)
