@@ -4,8 +4,5 @@ from prettyqt import core
 from prettyqt.qt import QtCore
 
 
-QtCore.QBuffer.__bases__ = (core.IODevice,)
-
-
-class Buffer(QtCore.QBuffer):
+class Buffer(core.IODeviceMixin, QtCore.QBuffer):
     pass
