@@ -7,7 +7,6 @@ import itertools
 from typing import Any, DefaultDict, TypeVar
 
 from prettyqt import constants, core
-import prettyqt.qt
 from prettyqt.qt import QtCore
 from prettyqt.utils import helpers
 
@@ -17,7 +16,7 @@ T = TypeVar("T", bound=QtCore.QObject)
 counter_dict: DefaultDict = defaultdict(itertools.count)
 
 
-class Object(QtCore.QObject):
+class ObjectMixin:
     def __repr__(self):
         return f"{type(self).__name__}()"
 
@@ -38,7 +37,7 @@ class Object(QtCore.QObject):
         for klass in reversed(inspect.getmro(type(self))):
             if "serialize_fields" in klass.__dict__:
                 data = klass.serialize_fields(self)  # type: ignore
-                dct.update(data)
+                dct |= data
         return dct
 
     @contextlib.contextmanager
@@ -121,3 +120,7 @@ class Object(QtCore.QObject):
         if isinstance(interval, str):
             interval = helpers.parse_time(interval)
         return self.startTimer(interval, constants.TIMER_TYPE[timer_type])
+
+
+class Object(ObjectMixin, QtCore.QObject):
+    pass
