@@ -4,8 +4,5 @@ from prettyqt import core
 from prettyqt.qt import QtCore
 
 
-QtCore.QSaveFile.__bases__ = (core.FileDevice,)
-
-
-class SaveFile(QtCore.QSaveFile):
+class SaveFile(core.FileDeviceMixin, QtCore.QSaveFile):
     pass
