@@ -27,10 +27,8 @@ SCOPE = bidict(
 
 ScopeStr = Literal["user", "system"]
 
-QtCore.QSettings.__bases__ = (core.Object,)
 
-
-class Settings(QtCore.QSettings):
+class Settings(core.ObjectMixin, QtCore.QSettings):
     def __init__(self, *args, settings_id: str | None = None):
         super().__init__(*args)
         self.settings_id = settings_id
@@ -75,7 +73,7 @@ class Settings(QtCore.QSettings):
         return settings
 
     def as_dict(self) -> dict[str, Any]:
-        return {k: v for k, v in self.items()}
+        return dict(self.items())
 
     def set_value(self, key: str, value):
         if not self.applicationName():
@@ -134,6 +132,7 @@ class Settings(QtCore.QSettings):
         Args:
             fmt: the default format to use
             scope: the scope to use
+            path: the path to set
 
         Raises:
             InvalidParamError: invalid format or scope
