@@ -1,17 +1,13 @@
 from __future__ import annotations
 
-from collections.abc import Iterator
-from typing import Callable
+from collections.abc import Callable, Iterator
 
 from prettyqt import core
 from prettyqt.qt import QtCore
 from prettyqt.utils import types
 
 
-QtCore.QVariantAnimation.__bases__ = (core.AbstractAnimation,)
-
-
-class VariantAnimation(QtCore.QVariantAnimation):
+class VariantAnimationMixin(core.AbstractAnimationMixin):
     def __getitem__(self, value: float) -> types.Variant:
         return self.keyValueAt(value)
 
@@ -49,3 +45,7 @@ class VariantAnimation(QtCore.QVariantAnimation):
     def set_range(self, start, end):
         self.setStartValue(start)
         self.setEndValue(end)
+
+
+class VariantAnimation(VariantAnimationMixin, QtCore.QVariantAnimation):
+    pass
