@@ -1,34 +1,33 @@
-# -*- coding: utf-8 -*-
-"""
-"""
-
-import pathlib
+from __future__ import annotations
 
 from prettyqt import core, widgets
+from prettyqt.qt import QtWidgets
 
 
 class InputAndSlider(widgets.Widget):
+    value_changed = core.Signal(int)
 
-    value_changed = core.Signal(pathlib.Path)
-
-    def __init__(self, bounds=None, parent=None):
+    def __init__(
+        self,
+        bounds: tuple[int, int] | None = None,
+        parent: QtWidgets.QWidget | None = None,
+    ):
         super().__init__(parent)
         self.path = None
         layout = widgets.BoxLayout("horizontal", self)
         layout.set_margin(0)
         self.spinbox = widgets.SpinBox()
-        layout += self.spinbox
+        layout.add(self.spinbox)
         self.slider = widgets.Slider()
-        layout += self.slider
+        layout.add(self.slider)
         if bounds:
             self.set_range(*bounds)
         self.spinbox.valueChanged.connect(self.slider.set_value)
         self.slider.valueChanged.connect(self.spinbox.set_value)
+        self.spinbox.valueChanged.connect(self.value_changed)
 
-    # def __getstate__(self):
-    #     return dict(path=self.path,
-    #                 extensions=self.extensions,
-    #                 enabled=self.isEnabled())
+    def serialize_fields(self):
+        return dict(path=self.path)
 
     # def __setstate__(self, state):
     #     self.__init__(state["extensions"])
@@ -62,4 +61,5 @@ if __name__ == "__main__":
     btn.slider.set_tick_position("below")
     btn.set_value(4)
     btn.show()
-    app.exec_()
+    btn.value_changed.connect(print)
+    app.main_loop()
