@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Callable
 from queue import Empty, Queue
-from typing import Callable, Literal
+from typing import Literal
 
 from prettyqt import core, gui, widgets
 from prettyqt.qt import QtWidgets
