@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import Callable, Literal
+from collections.abc import Callable
+from typing import Literal
 
 from prettyqt import constants, gui, iconprovider, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -67,33 +68,22 @@ class SidebarWidget(widgets.MainWindow):
         area: AreaStr = "top",
     ):
         self.area.box.add(item)
-        # button = widgets.ToolButton()
-        # button.set_text(title)
-        # button.set_icon_size(40)
-        # button.setFixedSize(80, 80)
-        # button.set_icon(icon)
-        # button.clicked.connect(lambda: self.area.box.setCurrentWidget(item))
-        # self.sidebar.addWidget(button)
-        # self.sidebar.add_separator()
-        if area == "top":
-            act = widgets.Action(
-                text=title,
-                icon=icon,
-                shortcut=shortcut,
-                parent=self.sidebar,
-                checkable=True,
-                callback=lambda: self.set_tab(item),
-            )
-            self.sidebar.insertAction(self.spacer_action, act)
-        else:
-            act = self.sidebar.add_action(
-                label=title,
-                icon=icon,
-                callback=lambda: self.set_tab(item),
-                checkable=True,
-            )
-        button = self.sidebar.widgetForAction(act)
+        act = widgets.Action(
+            text=title,
+            icon=icon,
+            shortcut=shortcut,
+            parent=self.sidebar,
+            checkable=True,
+            callback=lambda: self.set_tab(item),
+        )
+        button = widgets.ToolButton(self.sidebar)
+        button.setDefaultAction(act)
         button.setFixedWidth(self.BUTTON_WIDTH)
+        button.set_style("text_below_icon")
+        if area == "top":
+            self.sidebar.insertWidget(self.spacer_action, button)
+        else:
+            self.sidebar.addWidget(button)
         if len(self.area.box) == 1:
             button.setChecked(True)
         self.button_map[item] = button
@@ -116,15 +106,17 @@ class SidebarWidget(widgets.MainWindow):
         self.button_map[widget].set_icon(icon)
 
     def _get_widget(self, item: str | int | widgets.Widget):
+        """Returns widget page specified by name, offset or content."""
         if isinstance(item, int):
             return self.area.box[item]
-        if isinstance(item, str):
+        elif isinstance(item, str):
             item = self.area.find_child(QtWidgets.QWidget, name=item, recursive=False)
             if item not in self.area.box:
                 raise ValueError("Layout does not contain the chosen widget")
         return item
 
     def _get_current_widget(self) -> QtWidgets.QWidget:
+        """Returns the currently selected widget page."""
         for k, v in self.button_map.items():
             if v.isChecked():
                 return k
@@ -155,10 +147,6 @@ class SidebarWidget(widgets.MainWindow):
         shortcut: str | None = None,
         area: AreaStr = "top",
     ):
-        # act = self.sidebar.add_action(label=title,
-        #                                      icon=icon,
-        #                                      callback=callback,
-        #                                      checkable=checkable)
         act = widgets.Action(
             text=title,
             icon=icon,
@@ -166,12 +154,14 @@ class SidebarWidget(widgets.MainWindow):
             checkable=checkable,
             callback=callback,
         )
-        if area == "top":
-            self.sidebar.insertAction(self.spacer_action, act)
-        if area == "bottom":
-            self.sidebar.addAction(act)
-        button = self.sidebar.widgetForAction(act)
+        button = widgets.ToolButton(self.sidebar)
+        button.setDefaultAction(act)
         button.setFixedWidth(self.BUTTON_WIDTH)
+        button.set_style("text_below_icon")
+        if area == "top":
+            self.sidebar.insertWidget(self.spacer_action, button)
+        else:
+            self.sidebar.addWidget(button)
         return act
 
 
