@@ -1,13 +1,10 @@
 from __future__ import annotations
 
 from prettyqt import core, gui
-from prettyqt.qt import QtGui
+from prettyqt.qt import API, QtGui
 
 
-QtGui.QImage.__bases__ = (gui.PaintDevice,)
-
-
-class Image(QtGui.QImage):
+class Image(gui.PaintDeviceMixin, QtGui.QImage):
     def __getstate__(self):
         return bytes(self)
 
@@ -42,7 +39,21 @@ class Image(QtGui.QImage):
             self.InvertMode.InvertRgba if invert_alpha else self.InvertMode.InvertRgb
         )
 
+    def as_bytes(self) -> bytes | None:
+        bits = self.bits()
+        if bits is None:
+            return None
+        match API:
+            case "pyqt5":
+                return bits.asstring(self.byteCount())
+            case "pyqt6":
+                return bits.asstring(self.sizeInBytes())
+            case "pyside6":
+                return bits.tobytes()
+
 
 if __name__ == "__main__":
-    image = Image()
-    bytes(image)
+    app = gui.app()
+    image = gui.Pixmap(100, 100).toImage()
+    image = Image(image)
+    print(len(bytes(image)))
