@@ -7,24 +7,28 @@ from prettyqt.qt.QtQml import (
     qmlRegisterType as register_qml_type,
     qmlClearTypeRegistrations as clear_type_registrations,
 )
-from .qmlparserstatus import QmlParserStatus
+from .qmlparserstatus import QmlParserStatus, QmlParserStatusMixin
 from .jsvalue import JSValue
 from .jsvalueiterator import JSValueIterator
-from .jsengine import JSEngine
-from .qmlengine import QmlEngine
+from .jsengine import JSEngine, JSEngineMixin
+from .qmlengine import QmlEngine, QmlEngineMixin
 from .qmlapplicationengine import QmlApplicationEngine
 from .qmlcomponent import QmlComponent
-from .qmlimageproviderbase import QmlImageProviderBase
+from .qmlimageproviderbase import QmlImageProviderBase, QmlImageProviderBaseMixin
 
 __all__ = [
     "register_qml_type",
     "clear_type_registrations",
     "QmlParserStatus",
+    "QmlParserStatusMixin",
     "JSValue",
     "JSValueIterator",
     "QmlEngine",
+    "QmlEngineMixin",
     "JSEngine",
+    "JSEngineMixin",
     "QmlApplicationEngine",
     "QmlComponent",
     "QmlImageProviderBase",
+    "QmlImageProviderBaseMixin",
 ]
