@@ -1,6 +1,6 @@
 """Provides QtCharts classes and functions."""
 
-from prettyqt.qt import PYQT5, PYQT6, PYSIDE2, PYSIDE6, PythonQtError
+from prettyqt.qt import PYQT5, PYQT6, PYSIDE6, PythonQtError
 
 
 if PYQT5:
@@ -19,12 +19,6 @@ elif PYQT6:
             "The QtChart module was not found. "
             "It needs to be installed separately for PyQt6."
         )
-elif PYSIDE2:
-    from PySide2.QtCharts import QtCharts
-
-    def __getattr__(name: str):
-        return getattr(QtCharts, name)
-
 
 elif PYSIDE6:
     from PySide6.QtCharts import *
