@@ -5,10 +5,7 @@ from prettyqt.qt import QtCore, QtHelp
 from prettyqt.utils import types
 
 
-QtHelp.QHelpContentWidget.__bases__ = (widgets.TreeView,)
-
-
-class HelpContentWidget(QtHelp.QHelpContentWidget):
+class HelpContentWidget(widgets.TreeViewMixin, QtHelp.QHelpContentWidget):
     def index_of(self, url: types.UrlType) -> QtCore.QModelIndex | None:
         if isinstance(url, str):
             url = QtCore.QUrl(url)
