@@ -6,11 +6,11 @@ contains QtQuick-based classes
 from .quicktextdocument import QuickTextDocument
 from .quickrendercontrol import QuickRenderControl
 from .quickimageresponse import QuickImageResponse
-from .quickimageprovider import QuickImageProvider
+from .quickimageprovider import QuickImageProvider, QuickImageProviderMixin
 from .quickasyncimageprovider import QuickAsyncImageProvider
 from .quickitemgrabresult import QuickItemGrabResult
 from .quickview import QuickView
-from .quickitem import QuickItem
+from .quickitem import QuickItem, QuickItemMixin
 from .quickpainteditem import QuickPaintedItem
 from .quickwindow import QuickWindow
 
@@ -18,12 +18,14 @@ from .quickwindow import QuickWindow
 __all__ = [
     "QuickView",
     "QuickItem",
+    "QuickItemMixin",
     "QuickWindow",
     "QuickPaintedItem",
     "QuickTextDocument",
     "QuickRenderControl",
     "QuickImageResponse",
     "QuickImageProvider",
+    "QuickImageProviderMixin",
     "QuickAsyncImageProvider",
     "QuickItemGrabResult",
 ]
