@@ -8,10 +8,10 @@ Contains QtCore-based classes
 from __future__ import annotations
 
 
-from .abstracttransition import AbstractTransition
+from .abstracttransition import AbstractTransition, AbstractTransitionMixin
 from .signaltransition import SignalTransition
-from .eventtransition import EventTransition
-from .abstractstate import AbstractState
+from .eventtransition import EventTransition, EventTransitionMixin
+from .abstractstate import AbstractState, AbstractStateMixin
 from .finalstate import FinalState
 from .historystate import HistoryState
 from .state import State
@@ -20,11 +20,14 @@ from .statemachine import StateMachine
 
 __all__ = [
     "AbstractState",
+    "AbstractStateMixin",
     "FinalState",
     "HistoryState",
     "State",
     "StateMachine",
     "AbstractTransition",
+    "AbstractTransitionMixin",
     "SignalTransition",
     "EventTransition",
+    "EventTransitionMixin",
 ]
