@@ -4,13 +4,14 @@ from prettyqt import core
 from prettyqt.qt import QtStateMachine
 
 
-QtStateMachine.QAbstractState.__bases__ = (core.Object,)
-
-
-class AbstractState(QtStateMachine.QAbstractState):
+class AbstractStateMixin(core.ObjectMixin):
     def serialize_fields(self):
         return dict(active=self.active())
 
 
+class AbstractState(AbstractStateMixin, QtStateMachine.QAbstractState):
+    pass
+
+
 if __name__ == "__main__":
     state = AbstractState()
