@@ -7,9 +7,6 @@ from prettyqt.qt import QtSvg
 from prettyqt.utils import types
 
 
-QtSvg.QSvgWidget.__bases__ = (widgets.Widget,)
-
-
-class SvgWidget(QtSvg.QSvgWidget):
+class SvgWidget(widgets.WidgetMixin, QtSvg.QSvgWidget):
     def load_file(self, path: types.PathType):
         self.load(os.fspath(path))
