@@ -5,10 +5,7 @@ from prettyqt.qt import QtGui, QtWidgets
 from prettyqt.utils import InvalidParamError, types
 
 
-QtWidgets.QAbstractButton.__bases__ = (widgets.Widget,)
-
-
-class AbstractButton(QtWidgets.QAbstractButton):
+class AbstractButtonMixin(widgets.WidgetMixin):
     def serialize_fields(self):
         return dict(
             text=self.text(),
@@ -115,6 +112,10 @@ class AbstractButton(QtWidgets.QAbstractButton):
         self.setChecked(state)
 
 
+class AbstractButton(AbstractButtonMixin, QtWidgets.QAbstractButton):
+    pass
+
+
 if __name__ == "__main__":
     app = widgets.app()
     widget = AbstractButton()
