@@ -4,10 +4,7 @@ from prettyqt import widgets
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QErrorMessage.__bases__ = (widgets.Dialog,)
-
-
-class ErrorMessage(QtWidgets.QErrorMessage):
+class ErrorMessage(widgets.DialogMixin, QtWidgets.QErrorMessage):
     pass
 
 
