@@ -19,11 +19,7 @@ LINE_WRAP_MODE = bidict(
 LineWrapModeStr = Literal["none", "widget_width"]
 
 
-QtWidgets.QPlainTextEdit.__bases__ = (widgets.AbstractScrollArea,)
-
-
-class PlainTextEdit(QtWidgets.QPlainTextEdit):
-
+class PlainTextEditMixin(widgets.AbstractScrollAreaMixin):
     value_changed = core.Signal()
 
     def __init__(
@@ -267,6 +263,10 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         return self.text()
 
 
+class PlainTextEdit(PlainTextEditMixin, QtWidgets.QPlainTextEdit):
+    pass
+
+
 if __name__ == "__main__":
     from prettyqt import custom_validators
 
