@@ -1,16 +1,12 @@
 from __future__ import annotations
 
-from typing import Callable
+from collections.abc import Callable
 
 from prettyqt import core, widgets
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QPushButton.__bases__ = (widgets.AbstractButton,)
-
-
-class PushButton(QtWidgets.QPushButton):
-
+class PushButtonMixin(widgets.AbstractButtonMixin):
     value_changed = core.Signal(bool)
 
     def __init__(
@@ -27,6 +23,10 @@ class PushButton(QtWidgets.QPushButton):
         self.toggled.connect(self.value_changed)
 
 
+class PushButton(PushButtonMixin, QtWidgets.QPushButton):
+    pass
+
+
 if __name__ == "__main__":
     app = widgets.app()
     widget = PushButton("This is a test")
