@@ -4,10 +4,7 @@ from prettyqt import gui, widgets
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QStylePainter.__bases__ = (gui.Painter,)
-
-
-class StylePainter(QtWidgets.QStylePainter):
+class StylePainter(gui.PainterMixin, QtWidgets.QStylePainter):
     def draw_complex_control(
         self,
         control: widgets.style.ComplexControlStr,
