@@ -4,10 +4,7 @@ from prettyqt import constants, widgets
 from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QTreeWidget.__bases__ = (widgets.TreeView,)
-
-
-class TreeWidget(QtWidgets.QTreeWidget):
+class TreeWidgetMixin(widgets.TreeViewMixin):
     def __contains__(self, other: QtWidgets.QTreeWidgetItem):
         return self.indexOfTopLevelItem(other) >= 0
 
@@ -16,6 +13,10 @@ class TreeWidget(QtWidgets.QTreeWidget):
         self.sortItems(column, order)
 
 
+class TreeWidget(TreeWidgetMixin, QtWidgets.QTreeWidget):
+    pass
+
+
 if __name__ == "__main__":
     app = widgets.app()
     widget = TreeWidget()
